ProcessRunFutureProcessResultsExt extension

run response helper.

on

Methods

pipe(String script) Future<List<ProcessResult>>

Available on Future<List<ProcessResult>>, provided by the ProcessRunFutureProcessResultsExt extension

Similar to the | on linux it allows to pipe the stdout of the ran commands as stdin to the next command.