errText property
String
get
errText
Join the out lines for a quick string access.
Implementation
String get errText => _shellProcessResult.errText;
Join the out lines for a quick string access.
String get errText => _shellProcessResult.errText;