ShellContextMixin mixin

Shell context mixin

Implemented types
Mixin applications
Available extensions

Properties

encoding → Encoding
Default shell encoding (systemEncoding on iOS)
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
path → Context
Path context.
no setteroverride
platform → ShellContextPlatform
Platform info
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shellEnvironment → ShellEnvironment
Shell environment
no setteroverride

Methods

close() → Future<void>
Close the context
override
copyWith({ShellEnvironment? shellEnvironment}) → ShellContext

Available on ShellContext, provided by the ShellContextExt extension

Copy with a new shell environment
newShellEnvironment({Map<String, String>? environment}) → ShellEnvironment
New shell environment
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runZoned<T>(Future<T> action()) → Future<T>

Available on ShellContext, provided by the ShellContextExt extension

Run in a zone,
shell({ShellOptions? options}) → Shell
New shell must set itself as a shell Context, shell environement is no longer relevent.
override
toString() → String
A string representation of this object.
inherited
which(String command, {ShellEnvironment? environment, bool includeParentEnvironment = true}) → Future<String?>
Which command.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited