ProcessRunFutureProcessResultsExt extension
run response helper.
- on
Methods
-
pipe(
String script) → Future< List< ProcessResult> > -
Available on Future<
Similar to theList< , provided by the ProcessRunFutureProcessResultsExt extensionProcessResult> >|on linux it allows to pipe the stdout of the ran commands as stdin to the next command.