which library
Functions
-
which(
String command, {Map< String, String> ? environment, bool includeParentEnvironment = true}) → Future<String?> - Find the command according to a given or current environment
-
whichSync(
String command, {Map< String, String> ? environment, bool includeParentEnvironment = true}) → String? - Find the command according to a given or current environment